<div align="center">
  <img width="500px" src="https://github.com/vra/bing_brush/blob/main/assets/logo.jpeg"/>
  
### One-line Image Generating Program Based on the Bing Image Createor (Powered by DALL·E 3)

</div>

---

Credit: The solution of invoking Bing Image Creator API is from <https://github.com/acheong08/BingImageCreator>.

## Installation
```bash
pip install bing_brush
```

## Usage
### CLI
```bash
bing_brush -c cookie.txt -p 'a cute panda eating bamboos' -o output_folder
```
### Python API
```python
brush = BingBrush(cookie='/path/to/cookie.txt')
brush.process(prompt='a cute panda eating bamboos', out_folder='output')
```


## TODO
+ [ ] unit test
+ [ ] support for obtaining cookie for os.env


## Logo
Logo of this project is generated by Bing Image, prompt:
> A minimalist logo vector image, square-shaped, with a magical brush implemented in Python language in the center, colorful, digitial art

## Contribution

##
